import { Component, OnInit, ViewChild } from '@angular/core';
import { IgxSpreadsheetComponent } from "igniteui-angular-spreadsheet/ES5/igx-spreadsheet-component";
import { ExcelUtility } from "../ExcelUtility";
import { WorksheetHyperlink } from "igniteui-angular-excel/ES5/WorksheetHyperlink";

import { CellFill } from "igniteui-angular-excel/ES5/CellFill";
import { Color } from 'igniteui-angular-core/ES5/Color';
import { ColorScaleType } from "igniteui-angular-excel/ES5/ColorScaleType";
import { FormatConditionAboveBelow } from "igniteui-angular-excel/ES5/FormatConditionAboveBelow";
import { FormatConditionIconSet } from "igniteui-angular-excel/ES5/FormatConditionIconSet";
import { FormatConditionOperator } from "igniteui-angular-excel/ES5/FormatConditionOperator";
import { FormatConditionTextOperator } from "igniteui-angular-excel/ES5/FormatConditionTextOperator";
import { FormatConditionTimePeriod } from "igniteui-angular-excel/ES5/FormatConditionTimePeriod";
import { FormatConditionTopBottom } from "igniteui-angular-excel/ES5/FormatConditionTopBottom";
import { WorkbookColorInfo } from "igniteui-angular-excel/ES5/WorkbookColorInfo";
import { SpreadsheetCellSelectionMode } from 'igniteui-angular-spreadsheet/ES5/SpreadsheetCellSelectionMode';
import { SpreadsheetEnterKeyNavigationDirection } from 'igniteui-angular-spreadsheet/ES5/SpreadsheetEnterKeyNavigationDirection';

@Component({
  selector: 'app-spreadsheet',
  templateUrl: './spreadsheet.component.html',
  styleUrls: ['./spreadsheet.component.css']
})
export class SpreadsheetComponent implements OnInit {

  @ViewChild("spreadsheet")
  public spreadsheet: IgxSpreadsheetComponent;

  public spreadsheetSelectionMode: string;
  public enterKeyNavDirection: string;
  public isProtected: boolean;
  public isFormulaBarVisible: boolean;
  public areGridlinesVisible: boolean;
  public areHeadersVisible: boolean;
  public isEnterKeyNavEnabled: boolean;
  public activeCellText: string;

  public spreadsheetZoomLevel: number;

  constructor() {
    this.spreadsheetSelectionMode = "Normal";
    this.isProtected = false;
    this.isFormulaBarVisible = true;
    this.areGridlinesVisible = true;
    this.areHeadersVisible = true;
    this.isEnterKeyNavEnabled = false;
    this.enterKeyNavDirection = "Down";
    this.spreadsheetZoomLevel = 100;
  }

  public onProtectedChanged(e: any) {
    // ***DOES NOT CURRENTLY WORK WITH WORKBOOK.PROTECT***
    if (e.target.checked) {
      this.spreadsheet.workbook.protect();
      this.spreadsheet.activeWorksheet.protect();
    }
    else {
      this.spreadsheet.workbook.unprotect();
      this.spreadsheet.activeWorksheet.unprotect();
      this.spreadsheet.workbook.worksheets().removeAt(1);
    }
  }

  public onTabBarAreaVisibilityChanged(e: any) {
    if (e.target.checked) {
      this.spreadsheet.workbook.windowOptions.tabBarVisible = true;
    }
    else {
      this.spreadsheet.workbook.windowOptions.tabBarVisible = false;
    }
  }

  ngOnInit() {    
  }

  public spreadsheetSelectionChanged(args: any) {
    const value = args.target.value;

    switch (value) {
      case "Normal": {
        this.spreadsheet.selectionMode = 0;
        break;
      }
      case "ExtendSelection": {
        this.spreadsheet.selectionMode = 1;
        break;
      }
      case "AddToSelection": {
        this.spreadsheet.selectionMode = 2;
        break;
      }
    }
  }

  public enterKeyNavDirectionChanged(args: any) {
    const value = args.target.value;

    switch (value) {
      case "Down": {
        this.spreadsheet.enterKeyNavigationDirection = 0;
        break;
      }
      case "Up": {
        this.spreadsheet.enterKeyNavigationDirection = 2;
        break;
      }
      case "Left": {
        this.spreadsheet.enterKeyNavigationDirection = 3;
        break;
      }
      case "Right": {
        this.spreadsheet.enterKeyNavigationDirection = 1;
        break;
      }
    }
  }

  public openFile(input: HTMLInputElement): void {
    if (input.files == null || input.files.length === 0) {
      return;
    }

    console.log("Files:" + input.files[0].name);

    ExcelUtility.load(input.files[0]).then((w) => {
      this.spreadsheet.workbook = w;
    }, (e) => {
      console.error("Workbook Load Error:" + e);
    });
  }
}
